@@ -80,7 +80,12 @@ const BookImage =  GObject.registerClass({
         // might as well just show generated cover
         // TODO: a slightly better way is to pack the tiny thumbnail inside the generated cover
         if (pixbuf.get_width() < 48) throw new Error('thumbnail too small')
-        this._image.set_from_pixbuf(scalePixbuf(pixbuf))
+
+        const factor = this.get_scale_factor()
+        const surface = Gdk.cairo_surface_create_from_pixbuf(
+            scalePixbuf(pixbuf, factor), factor, null)
+
+        this._image.set_from_surface(surface)
         this._image.get_style_context().add_class('foliate-book-image')
     }
 })
@@ -1284,9 +1289,13 @@ var LibraryWindow =  GObject.registerClass({
         const flag = GObject.BindingFlags.BIDIRECTIONAL | GObject.BindingFlags.SYNC_CREATE
         ;[this._startButtonStack, this._endButtonStack].forEach(stack =>
             this._stack.bind_property('visible-child-name', stack, 'visible-child-name', flag))
-        this.connect('notify::active-view', () => {
+
+        const updateViewButton = () =>
             this._viewButton.get_child().icon_name = this.active_view === 'grid'
                 ? 'view-list-symbolic' : 'view-grid-symbolic'
+        updateViewButton()
+        this.connect('notify::active-view', () => {
+            updateViewButton()
             this._updateLibraryStack()
         })
 
